CA19_Cl02.html
open | /cms/logout/ |
open | /admin/ |
type | id_username | admin
type | id_password | admin
clickAndWait | //input[@value='Iniciar sesión'] |
clickAndWait | link=Video |
clickAndWait | link=Añadir vídeo |
clickAndWait | _save |
verifyTextPresent | Please specify at least a video file or a video url |
verifyTextPresent | Este campo es obligatorio. |
verifyTextPresent | exact:Nombre: |
type | id_name | prueba
clickAndWait | _continue |
verifyTextPresent | Please specify at least a video file or a video url |
clickAndWait | link=Terminar sesión |